import { AppDispatch } from "store";
import NotificationI from "ui/domain/uiNotificationEntity";
import { search } from "ui/domain/uiService";
import * as actionTypes from "./uiActionTypes";
import useUIStorage from "./uiService";
/* -------------------------------------------------------------------------- */
/*                                  Searchbar                                 */
/* -------------------------------------------------------------------------- */
const setSearchbarShown = (shown: boolean) => (dispatch: any) =>
  dispatch({ type: actionTypes.SET_SEARCHABAR_SHOWN, payload: shown });
/* -------------------------------------------------------------------------- */
/*                                 Search flow                                */
/* -------------------------------------------------------------------------- */
const setSearchQuery = (payload: string) => (dispatch: any) =>
  dispatch({ type: actionTypes.SET_SEARCH_QUERY, payload });

const executeSearchQuery = (payload: string) => (dispatch: any) => {
  dispatch({ type: actionTypes.EXECUTE_SEARCH_QUERY });

  return search(payload).then((result) => {
    dispatch({ type: actionTypes.EXECUTE_SEARCH_SUCCESS });

    return result;
  });
};
/* -------------------------------------------------------------------------- */
/*                                   Drawer                                   */
/* -------------------------------------------------------------------------- */
const setDrawer = (shown: boolean) => (dispatch: any) => {
  useUIStorage().setItem("drawer", shown);
  dispatch({ type: actionTypes.SET_DRAWER_SHOWN, payload: shown });
};
const getDrawer = () => (dispatch: any) => {
  const shown = useUIStorage().getItem("drawer");
  dispatch({ type: actionTypes.SET_DRAWER_SHOWN, payload: shown });
};
/* -------------------------------------------------------------------------- */
/*                                Notifications                               */
/* -------------------------------------------------------------------------- */
const notifyAction =
  (notification: Omit<NotificationI, "uid">) => (dispatch: AppDispatch) => {
    dispatch({
      type: actionTypes.NOTIFICATION_ADD,
      payload: {
        ...notification,
        uid: Date.now() + Math.floor(Math.random() * 100),
      },
    });
  };
const removeNotificationAction =
  (id: NotificationI["uid"]) => (dispatch: AppDispatch) => {
    dispatch({ type: actionTypes.NOTIFICATION_REMOVE, payload: id });
  };

const removeAllNotificationsAction = () => (dispatch: AppDispatch) => {
  dispatch({type: actionTypes.NOTIFICATION_REMOVE_ALL});
} 

/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */
/* -------------------------------------------------------------------------- */
/*                                   Exports                                  */
/* -------------------------------------------------------------------------- */
export {
  setSearchbarShown,
  setSearchQuery,
  executeSearchQuery,
  setDrawer,
  getDrawer,
  notifyAction,
  removeNotificationAction,
  removeAllNotificationsAction,
};
